@@ -101,7 +101,13 @@
 
     print $fh "Sending to batch - auto,$defdom,$dcname,$dcdom ".join(":",@requests)."\n";
     my ($result,$logmsg) = &LONCAPA::batchcreatecourse::create_courses(\@requests,\%courseids,'auto',$defdom,$dcname,$dcdom);
-    print $fh "$result && $logmsg\n";
+    my $output;
+    if ($result ne '') {
+        $output = $result."\n";
+    }
+    if ($logmsg ne '') {
+        $output .= $logmsg."\n";    
+    }
 
 # Copy requests from pending directory to processed directory and unlink.
   foreach my $request (@requests) {  
@@ -121,7 +127,6 @@
         }
     }
 
-    my $output;
     foreach my $key (sort keys %courseids) {
         print $fh "created course: $key - $courseids{$key}\n";
         my $newcourse = &Apache::lonnet::escape($key.':'.$courseids{$key});
