@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 #
 #Automated Enrollment script
-# $Id: Autoenroll.pl,v 1.27 2007/05/15 06:19:53 raeburn Exp $
+# $Id: Autoenroll.pl,v 1.28 2007/12/05 02:04:02 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -75,11 +75,12 @@
         my %reply = ();
         my %LC_code = ();
         foreach my $key (sort keys %courses) {
-            my $crs;
-            if ($key =~ m/^($dom)_(\w+)$/) {
-                $crs = $2;
-            }
-
+            my %args = (
+                         one_time => 1,
+                       );
+            my %coursehash = &Apache::lonnet::coursedescription($key,\%args);
+            my $crs = $coursehash{'num'};
+            next if ($coursehash{'domain'} ne $dom);
 # Get course settings
             my %settings = &Apache::lonnet::dump('environment',$dom,$crs);
             %{$enrollvar{$crs}} = ();
