@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # chemical equation style response
 #
-# $Id: chemresponse.pm,v 1.73 2007/04/18 00:48:06 albertel Exp $
+# $Id: chemresponse.pm,v 1.75 2007/10/15 09:47:29 foxr Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -334,7 +334,11 @@ sub end_organicresponse {
 
     if ($target eq 'grade' || $target eq 'web' || $target eq 'answer' || 
 	$target eq 'tex' || $target eq 'analyze') {
-	&Apache::lonxml::increment_counter(&Apache::response::repetition());
+	&Apache::lonxml::increment_counter(&Apache::response::repetition(), 
+					   "$partid.$id"); # part.response
+	if ($target eq 'analyze') {
+	    &Apache::lonhomework::set_bubble_lines();
+	}
     }
     &Apache::response::end_response();
     return $result;
@@ -560,7 +564,7 @@ sub end_reactionresponse {
 
     if ($target eq 'grade' || $target eq 'web' || $target eq 'answer' || 
 	$target eq 'tex' || $target eq 'analyze') {
-	&Apache::lonxml::increment_counter(&Apache::response::repetition());
+	&Apache::lonxml::increment_counter(&Apache::response::repetition(), "$partid.$id");
     }
     &Apache::response::end_response();
     return $result;
