@@ -1,7 +1,7 @@
 # LearningOnline Network with CAPA
 # option list style responses
 #
-# $Id: optionresponse.pm,v 1.144 2007/06/26 20:51:53 albertel Exp $
+# $Id: optionresponse.pm,v 1.147 2007/10/15 09:47:29 foxr Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -71,6 +71,8 @@ sub start_optionresponse {
   } elsif ($target eq 'analyze') {
     my $part_id="$Apache::inputtags::part.$id";
     push (@{ $Apache::lonhomework::analyze{"parts"} },$part_id);
+    push (@{ $Apache::lonhomeowrk::analyze{"$part_id.bubble_lines"} }, 1);
+
   }
   return $result;
 }
@@ -275,7 +277,14 @@ sub end_foilgroup {
 	}
       }
     }
-    &Apache::lonxml::increment_counter(&getfoilcounts($max));
+    my $part_id     = $Apache::inputtags::part;
+    my $response_id = $Apache::inputtags::response[-1];
+    &Apache::lonxml::increment_counter(&getfoilcounts($max),
+				       "$part_id.$response_id");
+    if ($target eq 'analyze') {
+	&Apache::lonhomework::set_bubble_lines();
+    }
+
   } elsif ($target eq 'edit') {
     $result.=&Apache::edit::end_table();
   }
