@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # random labelling tool
 #
-# $Id: randomlabel.pm,v 1.89 2007/06/20 17:33:33 banghart Exp $
+# $Id: randomlabel.pm,v 1.90 2007/10/17 22:11:55 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -61,7 +61,6 @@ use Apache::File();
 use Apache::Constants qw(:common :http);
 use Image::Magick;
 use Apache::lonplot;
-use lib '/home/httpd/lib/perl/';
 use LONCAPA;
  
 
@@ -553,6 +552,14 @@ sub end_location {
 }
 
 # <label>$var_abc</label>
+sub insert_label {
+    my ($after) = @_;
+    my $depth = scalar(@Apache::lonxml::depthcounter);
+    $depth-- if ($after);
+    my $inset = "\t"x$depth;
+    return "\n$inset<label></label>";
+}
+
 sub start_label {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
     my $result='';
