@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: imsimportdocs.pm,v 1.20 2007/08/02 01:33:31 albertel Exp $
+# $Id: imsimportdocs.pm,v 1.21 2007/08/21 18:22:41 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -641,12 +641,12 @@ sub display_three {
             for (my $i=0; $i<@topurls; $i++) {
                 my $url = &unescape($topurls[$i]);
                 my $name = &unescape($topnames[$i]);
-                push @imports, $name, $url;
+                push(@imports, [$name, $url]);
             }
         } elsif ($toplevel eq 'newfolder') {
             my $url = &unescape("/uploaded/$cdom/$crs/$timenow/sequences/Top.sequence");
             my $name = &unescape("$env{'form.foldername'}");
-            push @imports, $name, $url;
+            push(@imports, [$name, $url]);
         }
         my $errtext='';
         my $fatal=0;
