@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # "About Me" Personal Information
 #
-# $Id: lonaboutme.pm,v 1.63 2007/05/23 21:44:11 albertel Exp $
+# $Id: lonaboutme.pm,v 1.65 2007/07/27 00:17:17 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -114,8 +114,9 @@ sub handler {
 # --------------------------------------- There is such a user, get environment
     my %courseenv=&Apache::lonnet::dump('environment',$cdom,$cnum);
     if ($target ne 'tex') {
+	my $rss_link = &Apache::lonrss::rss_link($cnum,$cdom);
 	my $start_page = 
-	    &Apache::loncommon::start_page("Personal Information",undef,
+	    &Apache::loncommon::start_page("Personal Information", $rss_link,
 					   {'function'       => $forcestudent,
  					    'domain'         => $cdom,
 					    'force_register' =>
@@ -327,7 +328,8 @@ sub aboutme_info {
 sub print_portfiles_link {
     my ($r,$is_course) = @_;
     my ($cdom,$cnum,$name) = &aboutme_info($r,$is_course);
-    my $filecounts = &portfolio_files($r,'showlink',undef,$is_course);
+    my $filecounts = &portfolio_files($r,'showlink',undef,$is_course,
+                                      $cdom,$cnum,$name);
     my $query_string = &build_query_string();
     my $output;
     my %lt = &Apache::lonlocal::texthash(
@@ -459,7 +461,8 @@ sub display_portfolio_files {
                &mt('Update display').'" />';
     $output .= '</form><br /><br />';
     $r->print($output);
-    my $filecounts = &portfolio_files($r,'listfiles',\%lt,$is_course);
+    my $filecounts = &portfolio_files($r,'listfiles',\%lt,$is_course,
+                                      $cdom,$cnum,$name);
     if (!($env{'user.name'} eq 'public' && $env{'user.domain'} eq 'public')) {
         my $query_string = &build_query_string();
         $r->print('<br /><br /><a href="/adm/'.$cdom.'/'.$cnum.
@@ -475,8 +478,7 @@ sub display_portfolio_files {
 }
 
 sub portfolio_files {
-    my ($r,$mode,$lt,$is_course) = @_;
-    my ($cdom,$cnum,$name) = &aboutme_info($r,$is_course);
+    my ($r,$mode,$lt,$is_course,$cdom,$cnum,$name) = @_;
     my $filecounts = {
                        withpass    => 0,
                        withoutpass => 0,
