@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # handler for DC-only modifiable course settings
 #
-# $Id: lonmodifycourse.pm,v 1.34 2007/10/06 04:32:49 raeburn Exp $
+# $Id: lonmodifycourse.pm,v 1.36 2007/12/14 00:24:11 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -33,7 +33,7 @@ use Apache::lonnet;
 use Apache::loncommon;
 use Apache::lonhtmlcommon;
 use Apache::lonlocal;
-use Apache::londropadd;
+use Apache::lonuserutils;
 use Apache::lonpickcourse;
 use LONCAPA::Enrollment;
 use lib '/home/httpd/lib/perl';
@@ -369,8 +369,8 @@ all settings except course code, course owner, and default authentication method
     unless ($curr_authtype eq '') {
         $curr_authfield = $curr_authtype.'arg';
     }
-    my $javascript_validations=&Apache::londropadd::javascript_validations('modifycourse',$krbdefdom,$curr_authtype,$curr_authfield);
-    my %param = ( formname => 'document.cmod',
+    my $javascript_validations=&Apache::lonuserutils::javascript_validations('modifycourse',$krbdefdom,$curr_authtype,$curr_authfield);
+    my %param = ( formname => 'document.'.$env{'form.phase'},
 	   kerb_def_dom => $krbdefdom,
 	   kerb_def_auth => $krbdef,
            mode => 'modifycourse',
@@ -437,7 +437,7 @@ all settings except course code, course owner, and default authentication method
     my $mainheader = &mt('Course settings modifiable by [_1] only.',$dctitle);
     my $hidden_elements = &hidden_form_elements();
     $r->print(<<ENDDOCUMENT);
-<form action="/adm/modifycourse" method="post" name="cmod">
+<form action="/adm/modifycourse" method="post" name="$env{'form.phase'}">
 <h3>$mainheader</h3>
 </p><p>
 <table width="100%" cellspacing="6" cellpadding="6">
@@ -807,31 +807,36 @@ sub print_footer {
 sub check_course {
     my ($r,$dom,$domdesc) = @_;
     my ($ok_course,$description,$instcode,$owner);
-    if (defined($env{'form.pickedcourse'})) {
-        my ($cdom,$cnum) = split(/_/,$env{'form.pickedcourse'});
-        if ($cdom eq $dom) {
-            my %courseIDs = &Apache::lonnet::courseiddump($cdom,'.',1,'.','.',
-                                               $cnum,undef,undef,'.');
-            if (keys(%courseIDs) > 0) {
-                $ok_course = 'ok';
-                my ($description,$instcode,$owner);
-                if (ref($courseIDs{$cdom.'_'.$cnum}) eq 'HASH') {
-                    $description = $courseIDs{$cdom.'_'.$cnum}{'description'};
-                    $instcode = $courseIDs{$cdom.'_'.$cnum}{'inst_code'};
-                    $owner = $courseIDs{$cdom.'_'.$cnum}{'owner'};          
-                } else {
-                    ($description,$instcode,$owner) = 
-                                       split(/:/,$courseIDs{$cdom.'_'.$cnum});
-                }
-                $description = &unescape($description);
-                $instcode = &unescape($instcode);
-                if ($instcode) {
-                    $description .= " ($instcode)";
-                } 
+    my %args = (
+                 one_time => 1,
+               );
+    my %coursehash = 
+        &Apache::lonnet::coursedescription($env{'form.pickedcourse'},\%args);
+    my $cnum = $coursehash{'num'};
+    my $cdom = $coursehash{'domain'};
+    if ($cdom eq $dom) {
+        my $description;
+        my %courseIDs = &Apache::lonnet::courseiddump($cdom,'.',1,'.','.',
+                                           $cnum,undef,undef,'.');
+        if (keys(%courseIDs) > 0) {
+            $ok_course = 'ok';
+            my ($instcode,$owner);
+            if (ref($courseIDs{$cdom.'_'.$cnum}) eq 'HASH') {
+                $description = $courseIDs{$cdom.'_'.$cnum}{'description'};
+                $instcode = $courseIDs{$cdom.'_'.$cnum}{'inst_code'};
+                $owner = $courseIDs{$cdom.'_'.$cnum}{'owner'};          
+            } else {
+                ($description,$instcode,$owner) = 
+                                   split(/:/,$courseIDs{$cdom.'_'.$cnum});
             }
+            $description = &unescape($description);
+            $instcode = &unescape($instcode);
+            if ($instcode) {
+                $description .= " ($instcode)";
+            }
+            return ($ok_course,$description);
         }
     }
-    return ($ok_course,$description);
 }
 
 sub course_settings_descrip {
