@@ -1,5 +1,5 @@
 #
-# $Id: Spreadsheet.pm,v 1.73.2.1 2007/01/25 22:00:07 albertel Exp $
+# $Id: Spreadsheet.pm,v 1.77 2007/01/23 18:22:47 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -675,6 +675,21 @@ sub MAXPARM {
     return $max;
 }
 
+
+=pod
+
+=item PARM(parametername)
+
+Returns the value of the parameter matching the input parameter name.
+parametername should be a string such as 'parameter_1_opendate'.
+
+=cut
+
+#-------------------------------------------------------
+sub PARM {
+    return $c{$_[0]};
+}
+
 #-------------------------------------------------------
 
 =pod
@@ -805,7 +820,7 @@ sub expandnamed {
     my $self = shift;
     my $expression=shift;
     if ($expression=~/^\&/) {
-	my ($func,$var,$formula)=($expression=~/^\&(\w+)\(([^\;]+)\;(.*)\)/);
+	my ($func,$var,$formula)=($expression=~/^\&(\w+)\(([^\;]+)\;(.*)\)/s);
 	my @vars=split(/\W+/,$formula);
 	# make the list uniq
 	@vars = keys(%{{ map { $_ => 1 } @vars }});
@@ -813,12 +828,12 @@ sub expandnamed {
 	foreach my $varname ( @vars ) {
             if ($varname=~/^(parameter|stores|timestamp)/) {
                 $formula=~s/$varname/'$c{\''.$varname.'\'}'/ge;
-               $varname=~s/$var/\([\\w:\\- ]\+\)/g;
-	       foreach (keys(%{$self->{'constants'}})) {
-		  if ($_=~/$varname/) {
-		      $values{$1}=1;
-                  }
-               }
+		$varname=~s/$var/\([\\w:\\- ]\+\)/g;
+		foreach (keys(%{$self->{'constants'}})) {
+		    if ($_=~/$varname/) {
+			$values{$1}=1;
+		    }
+		}
 	    }
         }
         if ($func eq 'EXPANDSUM') {
@@ -892,7 +907,7 @@ sub sett {
             # Replace 'A0' with the value from 'A0'
             $t{$cell}=~s/(^|[^\"\'])([A-Za-z]\d+)/$1\$sheet_values\{\'$2\'\}/g;
             # Replace parameters
-            $t{$cell}=~s/(^|[^\"\'])\[([^\]]+)\]/$1.$self->expandnamed($2)/ge;
+            $t{$cell}=~s/(^|[^\"\'])\[([^\]]+)\]/$1.$self->expandnamed($2)/sge;
         }
     }
     #
@@ -904,7 +919,7 @@ sub sett {
             $t{$cell}=$formula;
             $t{$cell}=~s/\.\.+/\,/g;
             $t{$cell}=~s/(^|[^\"\'])([A-Za-z]\d+)/$1\$sheet_values\{\'$2\'\}/g;
-            $t{$cell}=~s/(^|[^\"\'])\[([^\]]+)\]/$1.$self->expandnamed($2)/ge;
+            $t{$cell}=~s/(^|[^\"\'])\[([^\]]+)\]/$1.$self->expandnamed($2)/sge;
         } elsif  ( $col  =~ /^[A-Z]$/  ) {
             if ($formula !~ /^\!/ && exists($self->{'constants'}->{$cell})
 		&& $self->{'constants'}->{$cell} ne '') {
@@ -915,7 +930,7 @@ sub sett {
             $t{$cell}=$formula;
             $t{$cell}=~s/\.\.+/\,/g;
             $t{$cell}=~s/(^|[^\"\'])([A-Za-z]\d+)/$1\$sheet_values\{\'$2\'\}/g;
-            $t{$cell}=~s/(^|[^\"\'])\[([^\]]+)\]/$1.$self->expandnamed($2)/ge;
+            $t{$cell}=~s/(^|[^\"\'])\[([^\]]+)\]/$1.$self->expandnamed($2)/sge;
         }
     }
     %{$self->{'safe'}->varglob('t')}=%t;
