@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Publication Handler
 #
-# $Id: lonpublisher.pm,v 1.228 2007/08/07 01:52:44 albertel Exp $
+# $Id: lonpublisher.pm,v 1.229 2007/09/24 13:59:09 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1131,6 +1131,11 @@ sub publish {
 	    '</span></h1><p><span class="LC_warning">'.
 	    &mt('If this resource is in active use, student performance data from the previous version may become inaccessible.').'</span></p><hr />';
     }
+    if ($metadatafields{'copyright'} eq 'priv') {
+        $scrout.='</p><h1><span class="LC_warning">'.&mt('Warning!').
+            '</span></h1><p><span class="LC_warning">'.
+            &mt('Copyright/distribution option "Private" is no longer supported. Select another option from below. Consider "Custom Rights" for maximum control over the usage of your resource.').'</span></p><hr />';
+    }
 
 # ------------------------------------------------------- Now have all metadata
 
@@ -1290,6 +1295,9 @@ END
 	$metadatafields{'copyright'}='default';
 	$metadatafields{'sourceavail'}='open';
     }
+    if ($metadatafields{'copyright'} eq 'priv') {
+        $metadatafields{'copyright'}='domain';
+    }
 # ------------------------------------------------ Dial in reasonable defaults
     my $defaultoption=$metadatafields{'copyright'};
     unless ($defaultoption) { $defaultoption='default'; }
@@ -1306,12 +1314,12 @@ END
 	    $intr_scrout.=&selectbox('Copyright/Distribution','copyright',
 				     $defaultoption,
 				     \&Apache::loncommon::copyrightdescription,
-				    (grep !/^public$/,(&Apache::loncommon::copyrightids)));
+				    (grep !/^(public|priv)$/,(&Apache::loncommon::copyrightids)));
 	} else {
 	    $intr_scrout.=&selectbox('Copyright/Distribution','copyright',
 				     $defaultoption,
 				     \&Apache::loncommon::copyrightdescription,
-				     (&Apache::loncommon::copyrightids));
+				     (grep !/^priv$/,(&Apache::loncommon::copyrightids)));
 	}
 	my $copyright_help =
 	    Apache::loncommon::help_open_topic('Publishing_Copyright');
