@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Construct and maintain state and binary representation of course for user
 #
-# $Id: lonuserstate.pm,v 1.119.2.1 2007/10/29 18:51:00 albertel Exp $
+# $Id: lonuserstate.pm,v 1.127 2007/12/01 03:43:49 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -56,6 +56,7 @@ my $retfrid; # variable with the very first RID in the course
 my $retfurl; # first URL
 my %randompick; # randomly picked resources
 my %randompickseed; # optional seed for randomly picking resources
+my %randomorder; # maps to order contents randomly
 my %encurl; # URLs in this folder are supposed to be encrypted
 my %hiddenurl; # this URL (or complete folder) is supposed to be hidden
 
@@ -106,9 +107,11 @@ sub processversionfile {
 # --------------------------------------------------------- Loads map from disk
 
 sub loadmap { 
-    my $uri=shift;
+    my ($uri,$parent_rid)=@_;
     if ($hash{'map_pc_'.$uri}) { 
-	$errtext.=&mt('<br />Multiple use of sequence/page <tt>[_1]</tt>! The course will not function properly.',$uri);
+	$errtext.='<p class="LC_error">'.
+	    &mt('Multiple use of sequence/page [_1]! The course will not function properly.','<tt>'.$uri.'</tt>').
+	    '</p>';
 	return; 
     }
     $pc++;
@@ -129,196 +132,280 @@ sub loadmap {
 
     my $instr=&Apache::lonnet::getfile($fn);
 
-    unless ($instr eq -1) {
+    if ($instr eq -1) {
+        $errtext.=&mt('<br />Map not loaded: The file <tt>[_1]</tt> does not exist.',$fn);
+	return;
+    }
 
 # Successfully got file, parse it
 
-        my $parser = HTML::TokeParser->new(\$instr);
-	$parser->attr_encoded(1);
-        my $token;
+    my $parser = HTML::TokeParser->new(\$instr);
+    $parser->attr_encoded(1);
+    # first get all parameters
+    while (my $token = $parser->get_token) {
+	next if ($token->[0] ne 'S');
+	if ($token->[1] eq 'param') {
+	    &parse_param($token,$lpc);
+	} 
+    }
+    #reset parser
+    $parser = HTML::TokeParser->new(\$instr);
+    $parser->attr_encoded(1);
 
-        my $linkpc=0;
+    my $linkpc=0;
 
-        $fn=~/\.(\w+)$/;
+    $fn=~/\.(\w+)$/;
 
-        $hash{'map_type_'.$lpc}=$1;
+    $hash{'map_type_'.$lpc}=$1;
 
-        while ($token = $parser->get_token) {
-	    if ($token->[0] eq 'S') {
-                if ($token->[1] eq 'resource') {
-# -------------------------------------------------------------------- Resource
-                    if ($token->[2]->{'type'} eq 'zombie') { next; }
-                    my $rid=$lpc.'.'.$token->[2]->{'id'};
+    my $randomize = ($randomorder{$parent_rid} =~ /^yes$/i);
 
-                    $hash{'kind_'.$rid}='res';
-                    $hash{'title_'.$rid}=$token->[2]->{'title'};
-                    my $turi=&versiontrack($token->[2]->{'src'});
-                    if ($token->[2]->{'version'}) {
-			unless ($hash{'version_'.$turi}) {
-			    $hash{'version_'.$turi}=$1;
-			}
-		    }
-		    my $title=$token->[2]->{'title'};
-		    $title=~s/\&colon\;/\:/gs;
-#		    my $symb=&Apache::lonnet::encode_symb($uri,
-#							  $token->[2]->{'id'},
-#							  $turi);
-#		    &Apache::lonnet::do_cache_new('title',$symb,$title);
-                    unless ($ispage) {
-                        $turi=~/\.(\w+)$/;
-                        my $embstyle=&Apache::loncommon::fileembstyle($1);
-                        if ($token->[2]->{'external'} eq 'true') { # external
-                            $turi=~s/^http\:\/\//\/adm\/wrapper\/ext\//;
-                        } elsif ($turi=~/^\/*uploaded\//) { # uploaded
-			    if (($embstyle eq 'img') 
-				|| ($embstyle eq 'emb')
-				|| ($embstyle eq 'wrp')) {
-                                $turi='/adm/wrapper'.$turi;
-			    } elsif ($embstyle eq 'ssi') {
-				#do nothing with these
-			    } elsif ($turi!~/\.(sequence|page)$/) {
-				$turi='/adm/coursedocs/showdoc'.$turi;
-                            }
-                        } elsif ($turi=~/\S/) { # normal non-empty internal resource
-			    my $mapdir=$uri;
-			    $mapdir=~s/[^\/]+$//;
-			    $turi=&Apache::lonnet::hreflocation($mapdir,$turi);
-			    if (($embstyle eq 'img') 
-				|| ($embstyle eq 'emb')
-				|| ($embstyle eq 'wrp')) {
-				$turi='/adm/wrapper'.$turi;
-			    }
-                        }
-		    }
-# Store reverse lookup, remove query string
-		    my $idsuri=$turi;
-		    $idsuri=~s/\?.+$//;
-                    if (defined($hash{'ids_'.$idsuri})) {
-                        $hash{'ids_'.$idsuri}.=','.$rid;
-                    } else {
-                        $hash{'ids_'.$idsuri}=''.$rid;
-                    }
-               
-                    if ($turi=~/\/(syllabus|aboutme|navmaps|smppg|bulletinboard)$/) {
-			$turi.='?register=1';
-		    }
-
-                    $hash{'src_'.$rid}=$turi;
-
-                    if ($token->[2]->{'external'} eq 'true') {
-                        $hash{'ext_'.$rid}='true:';
-                    } else {
-                        $hash{'ext_'.$rid}='false:';
-                    }
-                    if ($token->[2]->{'type'}) {
-			$hash{'type_'.$rid}=$token->[2]->{'type'};
-                        if ($token->[2]->{'type'} eq 'start') {
-			    $hash{'map_start_'.$uri}="$rid";
-                        }
-                        if ($token->[2]->{'type'} eq 'finish') {
-			    $hash{'map_finish_'.$uri}="$rid";
-                        }
-                    }  else {
-                        $hash{'type_'.$rid}='normal';
-                    }
-
-                    if (($turi=~/\.sequence$/) ||
-                        ($turi=~/\.page$/)) {
-                        $hash{'is_map_'.$rid}=1;
-                        &loadmap($turi);
-                    } 
-                    
-                } elsif ($token->[1] eq 'condition') {
-# ------------------------------------------------------------------- Condition
-
-                    my $rid=$lpc.'.'.$token->[2]->{'id'};
-
-                    $hash{'kind_'.$rid}='cond';
-		    my $condition = $token->[2]->{'value'};
-		    $condition =~ s/[\n\r]+/ /gs; 
-                    push(@cond, $condition);
-                    $hash{'condid_'.$rid}=$#cond;
-                    if ($token->[2]->{'type'}) {
-                        $cond[$#cond].=':'.$token->[2]->{'type'};
-                    }  else {
-                        $cond[$#cond].=':normal';
-                    }
-
-                } elsif ($token->[1] eq 'link') {
+    my @map_ids;
+    while (my $token = $parser->get_token) {
+	next if ($token->[0] ne 'S');
+	if ($token->[1] eq 'resource') {
+	    push(@map_ids,&parse_resource($token,$lpc,$ispage,$uri));
+	} elsif ($token->[1] eq 'link' && !$randomize) {
 # ----------------------------------------------------------------------- Links
+	    &make_link(++$linkpc,$lpc,$token->[2]->{'to'},
+		       $token->[2]->{'from'},
+		       $token->[2]->{'condition'});
+	} elsif ($token->[1] eq 'condition' && !$randomize) {
+	    &parse_condition($token,$lpc);
+	}
+    }
 
-                    $linkpc++;
-                    my $linkid=$lpc.'.'.$linkpc;
+    if ($randomize) {
+	if (!$env{'request.role.adv'}) {
+	    my $seed;
+	    if (defined($randompickseed{$parent_rid})) {
+		$seed = $randompickseed{$parent_rid};
+	    } else {
+		my ($mapid,$resid)=split(/\./,$parent_rid);
+		my $symb=
+		    &Apache::lonnet::encode_symb($hash{'map_id_'.$mapid},
+						 $resid,$hash{'src_'.$parent_rid});
+		
+		$seed = $symb;
+	    }
+	
+	    my $rndseed=&Apache::lonnet::rndseed($seed);
+	    &Apache::lonnet::setup_random_from_rndseed($rndseed);
+	    @map_ids=&Math::Random::random_permutation(@map_ids);
+	}
+	my $from = shift(@map_ids);
+	my $from_rid = $lpc.'.'.$from;
+	$hash{'map_start_'.$uri} = $from_rid;
+	$hash{'type_'.$from_rid}='start';
 
-                    my $goesto=$lpc.'.'.$token->[2]->{'to'};
-                    my $comesfrom=$lpc.'.'.$token->[2]->{'from'};
-                    my $undercond=0;
+	while (my $to = shift(@map_ids)) {
+	    &make_link(++$linkpc,$lpc,$to,$from);
+	    my $to_rid =  $lpc.'.'.$to;
+	    $hash{'type_'.$to_rid}='normal';
+	    $from = $to;
+	    $from_rid = $to_rid;
+	}
 
-                    if ($token->[2]->{'condition'}) {
-			$undercond=$lpc.'.'.$token->[2]->{'condition'};
-                    }
+	$hash{'map_finish_'.$uri}= $from_rid;
+	$hash{'type_'.$from_rid}='finish';
+    }
 
-                    $hash{'goesto_'.$linkid}=$goesto;
-                    $hash{'comesfrom_'.$linkid}=$comesfrom;
-                    $hash{'undercond_'.$linkid}=$undercond;
+    $parser = HTML::TokeParser->new(\$instr);
+    $parser->attr_encoded(1);
+    # last parse out the mapalias params so as to ignore anything
+    # refering to non-existant resources
+    while (my $token = $parser->get_token) {
+	next if ($token->[0] ne 'S');
+	if ($token->[1] eq 'param') {
+	    &parse_mapalias_param($token,$lpc);
+	} 
+    }
+}
+
+
+# -------------------------------------------------------------------- Resource
+sub parse_resource {
+    my ($token,$lpc,$ispage,$uri) = @_;
+    if ($token->[2]->{'type'} eq 'zombie') { next; }
+    my $rid=$lpc.'.'.$token->[2]->{'id'};
+	    
+    $hash{'kind_'.$rid}='res';
+    $hash{'title_'.$rid}=$token->[2]->{'title'};
+    my $turi=&versiontrack($token->[2]->{'src'});
+    if ($token->[2]->{'version'}) {
+	unless ($hash{'version_'.$turi}) {
+	    $hash{'version_'.$turi}=$1;
+	}
+    }
+    my $title=$token->[2]->{'title'};
+    $title=~s/\&colon\;/\:/gs;
+#   my $symb=&Apache::lonnet::encode_symb($uri,
+#					  $token->[2]->{'id'},
+#					  $turi);
+#   &Apache::lonnet::do_cache_new('title',$symb,$title);
+    unless ($ispage) {
+	$turi=~/\.(\w+)$/;
+	my $embstyle=&Apache::loncommon::fileembstyle($1);
+	if ($token->[2]->{'external'} eq 'true') { # external
+	    $turi=~s/^http\:\/\//\/adm\/wrapper\/ext\//;
+	} elsif ($turi=~/^\/*uploaded\//) { # uploaded
+	    if (($embstyle eq 'img') 
+		|| ($embstyle eq 'emb')
+		|| ($embstyle eq 'wrp')) {
+		$turi='/adm/wrapper'.$turi;
+	    } elsif ($embstyle eq 'ssi') {
+		#do nothing with these
+	    } elsif ($turi!~/\.(sequence|page)$/) {
+		$turi='/adm/coursedocs/showdoc'.$turi;
+	    }
+	} elsif ($turi=~/\S/) { # normal non-empty internal resource
+	    my $mapdir=$uri;
+	    $mapdir=~s/[^\/]+$//;
+	    $turi=&Apache::lonnet::hreflocation($mapdir,$turi);
+	    if (($embstyle eq 'img') 
+		|| ($embstyle eq 'emb')
+		|| ($embstyle eq 'wrp')) {
+		$turi='/adm/wrapper'.$turi;
+	    }
+	}
+    }
+# Store reverse lookup, remove query string
+    my $idsuri=$turi;
+    $idsuri=~s/\?.+$//;
+    if (defined($hash{'ids_'.$idsuri})) {
+	$hash{'ids_'.$idsuri}.=','.$rid;
+    } else {
+	$hash{'ids_'.$idsuri}=''.$rid;
+    }
+    
+    if ($turi=~/\/(syllabus|aboutme|navmaps|smppg|bulletinboard)$/) {
+	$turi.='?register=1';
+    }
+    
+    $hash{'src_'.$rid}=$turi;
+    
+    if ($token->[2]->{'external'} eq 'true') {
+	$hash{'ext_'.$rid}='true:';
+    } else {
+	$hash{'ext_'.$rid}='false:';
+    }
+    if ($token->[2]->{'type'}) {
+	$hash{'type_'.$rid}=$token->[2]->{'type'};
+	if ($token->[2]->{'type'} eq 'start') {
+	    $hash{'map_start_'.$uri}="$rid";
+	}
+	if ($token->[2]->{'type'} eq 'finish') {
+	    $hash{'map_finish_'.$uri}="$rid";
+	}
+    }  else {
+	$hash{'type_'.$rid}='normal';
+    }
+    
+    if (($turi=~/\.sequence$/) ||
+	($turi=~/\.page$/)) {
+	$hash{'is_map_'.$rid}=1;
+	&loadmap($turi,$rid);
+    } 
+    return $token->[2]->{'id'};
+}
+
+sub make_link {
+    my ($linkpc,$lpc,$to,$from,$condition) = @_;
+    
+    my $linkid=$lpc.'.'.$linkpc;
+    my $goesto=$lpc.'.'.$to;
+    my $comesfrom=$lpc.'.'.$from;
+    my $undercond=0;
+
+    if ($condition) {
+	$undercond=$lpc.'.'.$condition;
+    }
+
+    $hash{'goesto_'.$linkid}=$goesto;
+    $hash{'comesfrom_'.$linkid}=$comesfrom;
+    $hash{'undercond_'.$linkid}=$undercond;
+
+    if (defined($hash{'to_'.$comesfrom})) {
+	$hash{'to_'.$comesfrom}.=','.$linkid;
+    } else {
+	$hash{'to_'.$comesfrom}=''.$linkid;
+    }
+    if (defined($hash{'from_'.$goesto})) {
+	$hash{'from_'.$goesto}.=','.$linkid;
+    } else {
+	$hash{'from_'.$goesto}=''.$linkid;
+    }
+}
+
+# ------------------------------------------------------------------- Condition
+sub parse_condition {
+    my ($token,$lpc) = @_;
+    my $rid=$lpc.'.'.$token->[2]->{'id'};
+    
+    $hash{'kind_'.$rid}='cond';
+
+    my $condition = $token->[2]->{'value'};
+    $condition =~ s/[\n\r]+/ /gs;
+    push(@cond, $condition);
+    $hash{'condid_'.$rid}=$#cond;
+    if ($token->[2]->{'type'}) {
+	$cond[$#cond].=':'.$token->[2]->{'type'};
+    }  else {
+	$cond[$#cond].=':normal';
+    }
+}
 
-                    if (defined($hash{'to_'.$comesfrom})) {
-                        $hash{'to_'.$comesfrom}.=','.$linkid;
-                    } else {
-                        $hash{'to_'.$comesfrom}=''.$linkid;
-                    }
-                    if (defined($hash{'from_'.$goesto})) {
-                        $hash{'from_'.$goesto}.=','.$linkid;
-                    } else {
-                        $hash{'from_'.$goesto}=''.$linkid;
-                    }
-                } elsif ($token->[1] eq 'param') {
 # ------------------------------------------------------------------- Parameter
 
-                    my $referid=$lpc.'.'.$token->[2]->{'to'};
-		    my $name=$token->[2]->{'name'};
-		    my $part;
-		    if ($name=~/^parameter_(.*)_/) {
-			$part=$1;
-		    } else {
-			$part=0;
-		    }
-		    $name=~s/^.*_([^_]*)$/$1/;
-                    my $newparam=
-			&escape($token->[2]->{'type'}).':'.
-			&escape($part.'.'.$name).'='.
-			&escape($token->[2]->{'value'});
-                    if (defined($hash{'param_'.$referid})) {
-                        $hash{'param_'.$referid}.='&'.$newparam;
-                    } else {
-                        $hash{'param_'.$referid}=''.$newparam;
-                    }
-                    if ($token->[2]->{'name'}=~/^parameter_(0_)*mapalias$/) {
-			$hash{'mapalias_'.$token->[2]->{'value'}}=$referid;
-                    }
-                    if ($token->[2]->{'name'}=~/^parameter_(0_)*randompick$/) {
-			$randompick{$referid}=$token->[2]->{'value'};
-                    }
-                    if ($token->[2]->{'name'}=~/^parameter_(0_)*randompickseed$/) {
-			$randompickseed{$referid}=$token->[2]->{'value'};
-                    }
-                    if ($token->[2]->{'name'}=~/^parameter_(0_)*encrypturl$/) {
-			if ($token->[2]->{'value'}=~/^yes$/i) {
-			    $encurl{$referid}=1;
-			}
-                    }
-                    if ($token->[2]->{'name'}=~/^parameter_(0_)*hiddenresource$/) {
-			if ($token->[2]->{'value'}=~/^yes$/i) {
-			    $hiddenurl{$referid}=1;
-			}
-                    }
-                } 
-		
-            }
-        }
-
+sub parse_param {
+    my ($token,$lpc) = @_;
+    my $referid=$lpc.'.'.$token->[2]->{'to'};
+    my $name=$token->[2]->{'name'};
+    my $part;
+    if ($name=~/^parameter_(.*)_/) {
+	$part=$1;
     } else {
-        $errtext.=&mt('<br />Map not loaded: The file <tt>[_1]</tt> does not exist.',$fn);
+	$part=0;
+    }
+    $name=~s/^.*_([^_]*)$/$1/;
+    my $newparam=
+	&escape($token->[2]->{'type'}).':'.
+	&escape($part.'.'.$name).'='.
+	&escape($token->[2]->{'value'});
+    if (defined($hash{'param_'.$referid})) {
+	$hash{'param_'.$referid}.='&'.$newparam;
+    } else {
+	$hash{'param_'.$referid}=''.$newparam;
+    }
+    if ($token->[2]->{'name'}=~/^parameter_(0_)*randompick$/) {
+	$randompick{$referid}=$token->[2]->{'value'};
+    }
+    if ($token->[2]->{'name'}=~/^parameter_(0_)*randompickseed$/) {
+	$randompickseed{$referid}=$token->[2]->{'value'};
+    }
+    if ($token->[2]->{'name'}=~/^parameter_(0_)*randomorder$/) {
+	$randomorder{$referid}=$token->[2]->{'value'};
+    }
+    if ($token->[2]->{'name'}=~/^parameter_(0_)*encrypturl$/) {
+	if ($token->[2]->{'value'}=~/^yes$/i) {
+	    $encurl{$referid}=1;
+	}
+    }
+    if ($token->[2]->{'name'}=~/^parameter_(0_)*hiddenresource$/) {
+	if ($token->[2]->{'value'}=~/^yes$/i) {
+	    $hiddenurl{$referid}=1;
+	}
+    }
+}
+
+sub parse_mapalias_param {
+    my ($token,$lpc) = @_;
+    my $referid=$lpc.'.'.$token->[2]->{'to'};
+    return if (!exists($hash{'src_'.$referid}));
+
+    if ($token->[2]->{'name'}=~/^parameter_(0_)*mapalias$/) {
+	&count_mapalias($token->[2]->{'value'},$referid);
+	$hash{'mapalias_'.$token->[2]->{'value'}}=$referid;
     }
 }
 
@@ -350,7 +437,7 @@ sub simplify {
 sub traceroute {
     my ($sofar,$rid,$beenhere,$encflag,$hdnflag)=@_;
     my $newsofar=$sofar=simplify($sofar);
-    unless ($beenhere=~/\&$rid\&/) {
+    unless ($beenhere=~/\&\Q$rid\E\&/) {
 	$beenhere.=$rid.'&';  
 	my ($mapid,$resid)=split(/\./,$rid);
 	my $symb=&Apache::lonnet::encode_symb($hash{'map_id_'.$mapid},$resid,$hash{'src_'.$rid});
@@ -384,7 +471,8 @@ sub traceroute {
 	    if (defined($hash{'map_start_'.$hash{'src_'.$rid}})) {
 		$sofar=$newsofar=
 		    &traceroute($sofar,
-				$hash{'map_start_'.$hash{'src_'.$rid}},'&',
+				$hash{'map_start_'.$hash{'src_'.$rid}},
+				$beenhere,
 				$encflag || $encurl{$rid},
 				$hdnflag || $hiddenurl{$rid});
 	    }
@@ -581,13 +669,14 @@ sub readmap {
 	%parmhash=();
 	$errtext='';
 	$pc=0;
+	&clear_mapalias_count();
 	&processversionfile(%cenv);
 	my $furi=&Apache::lonnet::clutter($uri);
 	$hash{'src_0.0'}=&versiontrack($furi);
 	$hash{'title_0.0'}=&Apache::lonnet::metadata($uri,'title');
 	$hash{'ids_'.$furi}='0.0';
 	$hash{'is_map_0.0'}=1;
-	loadmap($uri);
+	loadmap($uri,'0.0');
 	if (defined($hash{'map_start_'.$uri})) {
 	    &Apache::lonnet::appenv("request.course.id"  => $short,
 				    "request.course.fn"  => $fn,
@@ -597,6 +686,7 @@ sub readmap {
 	    &accinit($uri,$short,$fn);
 	    &hiddenurls();
 	}
+	$errtext .= &get_mapalias_errors();
 # ------------------------------------------------------- Put versions into src
 	foreach my $key (keys(%hash)) {
 	    if ($key=~/^src_/) {
@@ -728,6 +818,43 @@ sub evalstate {
     return $state;
 }
 
+{
+    my %mapalias_cache;
+    sub count_mapalias {
+	my ($value,$resid) = @_;
+ 	push(@{ $mapalias_cache{$value} }, $resid);
+    }
+
+    sub get_mapalias_errors {
+	my $error_text;
+	foreach my $mapalias (sort(keys(%mapalias_cache))) {
+	    next if (scalar(@{ $mapalias_cache{$mapalias} } ) == 1);
+	    my $count;
+	    my $which =
+		join('</li><li>', 
+		     map {
+			 my $id = $_;
+			 if (exists($hash{'src_'.$id})) {
+			     $count++;
+			 }
+			 my ($mapid) = split(/\./,$id);
+                         &mt('Resource "[_1]" <br /> in Map "[_2]"',
+			     $hash{'title_'.$id},
+			     $hash{'title_'.$hash{'ids_'.$hash{'map_id_'.$mapid}}});
+		     } (@{ $mapalias_cache{$mapalias} }));
+	    next if ($count < 2);
+	    $error_text .= '<div class="LC_error">'.
+		&mt('Error: Found the mapalias "[_1]" defined multiple times.',
+		    $mapalias).
+		'</div><ul><li>'.$which.'</li></ul>';
+	}
+	&clear_mapalias_count();
+	return $error_text;
+    }
+    sub clear_mapalias_count {
+	undef(%mapalias_cache);
+    }
+}
 1;
 __END__
 
